#
# spec file for package arpack-ng
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libarpack2
%define plibname libparpack2
%define major 	2
%define minor 	0

%if 0%{?sles_version}
%define _mpi openmpi mvapich2
%else
%define _mpi openmpi
%endif

Name:           arpack-ng
Version:        3.2.0
Release:        4.5
Summary:        Fortran77 subroutines for solving large scale eigenvalue problems
License:        BSD-3-Clause
Group:          System/Libraries
Url:            https://github.com/opencollab/arpack-ng
Source0:        https://github.com/opencollab/arpack-ng/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Obsoletes:      arpack < %{version}
Provides:       arpack = %{version}
BuildRequires:  blas-devel
BuildRequires:  gcc-fortran
BuildRequires:  lapack-devel
%if 0%{?sles_version}
BuildRequires:  mvapich2-devel
%endif
BuildRequires:  openmpi-devel
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ARPACK is a collection of Fortran77 subroutines designed to solve 
large scale eigenvalue problems.

Arpack-ng is the successor of the legacy Arpack. It is fully compatible
with Arpack.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/Other
Requires:       %{libname} = %{version}-%{release}
Requires:       blas-devel
Requires:       gcc-fortran
Requires:       lapack-devel
Requires:       pkgconfig
Obsoletes:      arpack-devel < %{version}
Provides:       arpack-devel = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package     -n %{libname}
Summary:        Files needed for developing arpack based applications
Group:          System/Libraries
Provides:       %{libname}_%{major}_%{minor} = %{version}
Obsoletes:      %{libname}_%{major}_%{minor} < %{version}

%description -n %{libname}
ARPACK is a collection of Fortran77 subroutines designed to solve
large scale eigenvalue problems. This package contains the so
library links used for building arpack based applications.


%package     -n parpack-openmpi
Summary:        Development files for %{name}
Group:          Development/Libraries/Other
Requires:       %{plibname}-openmpi = %{version}

%description -n parpack-openmpi
ARPACK is a collection of Fortran77 subroutines designed to solve 
large scale eigenvalue problems.

Arpack-ng is the successor of the legacy Arpack. It is fully compatible
with Arpack.


%package     -n parpack-openmpi-devel
Summary:        Development files for %{name}
Group:          Development/Libraries/Parallel
Requires:       %{plibname}-openmpi = %{version}
Requires:       blas-devel
Requires:       lapack-devel
Requires:       openmpi-devel

%description     -n parpack-openmpi-devel
The %{name}-openmpi-devel package contains libraries and header files for
developing applications that use %{name}.


%package     -n %{plibname}-openmpi
Summary:        Files needed for developing arpack based applications
Group:          System/Libraries
Provides:       %{plibname}_%{major}_%{minor} = %{version}
Obsoletes:      %{plibname}_%{major}_%{minor} < %{version}

%description -n %{plibname}-openmpi
ARPACK is a collection of Fortran77 subroutines designed to solve
large scale eigenvalue problems. This package contains the so
library links used for building arpack based applications.


%if 0%{?sles_version}
%package     -n parpack-mvapich2
Summary:        Development files for %{name}
Group:          Development/Libraries/Parallel
Requires:       %{plibname}-mvapich2 = %{version}

%description     -n parpack-mvapich2
ARPACK is a collection of Fortran77 subroutines designed to solve 
large scale eigenvalue problems.

Arpack-ng is the successor of the legacy Arpack. It is fully compatible
with Arpack.

%package     -n parpack-mvapich2-devel
Summary:        Development files for %{name}
Group:          Development/Libraries/Parallel
Requires:       %{plibname}-mvapich2 = %{version}
Requires:       blas-devel
Requires:       lapack-devel
Requires:       mvapich2-devel

%description -n parpack-mvapich2-devel
The %{name}-mvapich2-devel package contains libraries and header files for
developing applications that use %{name}.


%package     -n %{plibname}-mvapich2
Summary:        Files needed for developing arpack based applications
Group:          System/Libraries
Provides:       %{plibname}_%{major}_%{minor} = %{version}
Obsoletes:      %{plibname}_%{major}_%{minor} < %{version}

%description -n %{plibname}-mvapich2
ARPACK is a collection of Fortran77 subroutines designed to solve
large scale eigenvalue problems. This package contains the so
library links used for building arpack based applications.
%endif

%prep
%setup -q
set -- *

cp -r EXAMPLES examples

for i in %_mpi
do
    mkdir arpack-ng-$i
    cp -ap "$@" arpack-ng-$i
done

%build
%configure --disable-static

make %{?_smp_mflags}

for i in %_mpi
do
cd arpack-ng-$i
   export F77=%{_libdir}/mpi/gcc/$i/bin/mpif77
   export MPIF77=%{_libdir}/mpi/gcc/$i/bin/mpif77
   export LD_LIBRARY_PATH=%{_libdir}/mpi/gcc/$i/%_lib
   %define _prefix /usr/%_lib/mpi/gcc/\$i
   %configure --disable-static \
              --enable-mpi
   make %{?_smp_mflags}
cd ..
done

# Set prefix to default value
%define _prefix /usr

%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'

for i in %_mpi
do
  cd arpack-ng-$i
   make install DESTDIR=%{buildroot}
   rm -rf %{buildroot}%{_libdir}/mpi/gcc/$i/%_lib/libarpack.*
  cd ..
done

%check
make check
for i in %_mpi
do
  cd arpack-ng-$i
  make check
  cd ..
done

%clean
rm -rf %{buildroot}

%post -n %{libname} -p /sbin/ldconfig

%postun -n%{libname} -p /sbin/ldconfig

%post -n%{plibname}-openmpi -p /sbin/ldconfig

%postun -n%{plibname}-openmpi -p /sbin/ldconfig

%if 0%{?sles_version}
%post -n%{plibname}-mvapich2 -p /sbin/ldconfig

%postun -n%{plibname}-mvapich2 -p /sbin/ldconfig
%endif

%files -n %{libname} 
%defattr(-,root,root,-)
%doc CHANGES COPYING README TODO
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%doc examples
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files -n parpack-openmpi
%defattr(-,root,root,-)
%{_libdir}/mpi/gcc/openmpi/bin/p??drv?

%files -n %{plibname}-openmpi
%defattr(-,root,root,-)
%{_libdir}/mpi/gcc/openmpi/%_lib/lib*arpack.so.*

%files -n parpack-openmpi-devel
%defattr(-,root,root,-)
%{_libdir}/mpi/gcc/openmpi/%_lib/libparpack.so
%{_libdir}/mpi/gcc/openmpi/%_lib/libparpack.la
%dir %{_libdir}/mpi/gcc/openmpi/%_lib/pkgconfig
%{_libdir}/mpi/gcc/openmpi/%_lib/pkgconfig/*.pc

%if 0%{?sles_version}
%files -n parpack-mvapich2
%defattr(-,root,root,-)
%{_libdir}/mpi/gcc/mvapich2/bin/p??drv?

%files -n %{plibname}-mvapich2
%defattr(-,root,root,-)
%{_libdir}/mpi/gcc/mvapich2/%_lib/libparpack.so.*

%files -n parpack-mvapich2-devel
%defattr(-,root,root,-)
%{_libdir}/mpi/gcc/mvapich2/%_lib/libparpack.so
%{_libdir}/mpi/gcc/mvapich2/%_lib/libparpack.la
%dir %{_libdir}/mpi/gcc/openmpi/%_lib/pkgconfig
%{_libdir}/mpi/gcc/mvapich2/%_lib/pkgconfig/*.pc
%endif

%changelog
* Sat Dec 13 2014 dmitry_r@opensuse.org
- Update to version 3.2.0
  * See included CHANGES file for details
  * Remove obsolete 0001-Do-not-install-test-binaries.patch
* Wed Jan  8 2014 badshah400@gmail.com
- Add baselibs.conf file for multiarch binaries.
* Tue Dec 10 2013 sweet_f_a@gmx.de
- Update to version 3.1.4
  * libparpack2: missing dependency on MPI:
    http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=718790
  * Replace LAPACK second function with ARPACK's own arscnd in PARPACK
  * Fix issue #1259 in DSEUPD and SSEUPD
    The Ritz vector purification step assumes workl(iq) still contains the
    original Q matrix. This is however overwritten by the call to xGEQR2
    earlier.
  * Use configure supplied blas and lapack in the pkg-config.
    Thanks to Ward Poelmans (Closes: #1320)
  * Switch to automake 1.14 + libtool 2.4.2.
    Thanks to Ward Poelmans (Closes: #1321)
  * dseupd routine may lead to a segmentation fault
    Thanks to Edouard Canot (Closes: #1323)
  * dsaupd and 'BE' option returns wrong eigenvalues for a SPD matrix
    Thanks to Edouard Canot (Closes: #1329)
- enable test suite
- add 0001-Do-not-install-test-binaries.patch to remove useless
  test binaries, this removes the whole default arpack-ng package
* Fri Sep  6 2013 dmitry_r@opensuse.org
- Update to version 3.1.3
  * Replace depcomp symlink with actual file.
  * Replace arpack.pc with proper autotooled arpack.pc.in
  * Add debug.h to TESTS/Makefile.am sources
  * "make dist" is functionnal
  * Also build the library "libparpacksrcblacs" (PARPACK/UTIL/BLACS/)
  * Wrong call to pdlamch was causing segfaults
  * Get rid of the mpif.h occurences in the source code
  * Configure detected built-in LAPACK and BLAS, but refused to use them
  * Fixed division by zero in smlnum by usind p[d,s]lamch instead of the
    serial
* Sun Aug 26 2012 scorot@free.fr
- fix source file Url
* Sun Aug 26 2012 scorot@free.fr
- fix borken obsoletes/provides in devel package
* Tue Jul 10 2012 scorot@free.fr
- version 3.1.1
  * Many bug fixes in the parpack lib. It is an old patch from
    upstream. Thanks to Viral Shah for pinging us on this subject.
    See the PARPACK_CHANGES file for the details.
  * Fixed a lack of appropriate bounds check in DNAUP2.
    Thanks to Pauli Virtanen for the patch (Closes: #632)
  * Update of the doc about TOL in dnaupd.
  * Reorder bug fixed when eigenvectors are requested and the
    resulting number of converged eigenvalues is less than the
    number requested. Patches from Tim Mitchell. (Closes: #664)
- spec file cleanup
* Thu Jun  7 2012 scorot@free.fr
- add missing requirements of blas and lapack in devel package
* Mon May 14 2012 scorot@free.fr
- Modify Requires of devel subpackages to match changes in lapack
  and blas packages
* Thu May 10 2012 scorot@free.fr
- Modify BuildRequires to match recent name changes of lapack and
  blas in project.
* Tue May  8 2012 scorot@free.fr
- link against reference blas and lapack instead of openblas
- build parallel parpack libs for openmpi and mvapich2
- add examples files in the doc of devel package
* Sun May  6 2012 scorot@free.fr
- spec file cleanup
- fix license flag
* Wed Mar 21 2012 scorot@free.fr
- add provides %%%%name in devel package
* Tue Feb 28 2012 scorot@free.fr
- add BuildRoot flag in order to fix build on SLE
- fix wrong library minor number
- fix wrong requirement in devel package
* Sun Feb 26 2012 scorot@free.fr
- initial package
- version 3.0.2
